@@ -56,10 +56,12 @@
 
 QT_BEGIN_NAMESPACE
 
+Q_LOGGING_CATEGORY(lcItemManagement, "qt.quick.controls.control.itemmanagement")
+
 /*!
     \qmltype Control
     \inherits Item
-    \instantiates QQuickControl
+//!     \instantiates QQuickControl
     \inqmlmodule QtQuick.Controls
     \since 5.7
     \brief Abstract base type providing functionality common to all controls.
@@ -156,9 +158,6 @@ QQuickControlPrivate::QQuickControlPrivate()
 
 QQuickControlPrivate::~QQuickControlPrivate()
 {
-#if QT_CONFIG(accessibility)
-    QAccessible::removeActivationObserver(this);
-#endif
 }
 
 void QQuickControlPrivate::init()
@@ -178,6 +177,20 @@ bool QQuickControlPrivate::acceptTouch(const QTouchEvent::TouchPoint &point)
         return true;
     }
 
+    // If the control is on a Flickable that has a pressDelay, the press is sent
+    // as a mouse event rather than touch; so it detect and deal with it.
+    if (touchId == -1 && pressWasTouch) {
+        const auto delta = QVector2D(point.pos() - previousPressPos);
+        const bool overThreshold = QQuickWindowPrivate::dragOverThreshold(delta);
+        if (point.state() == Qt::TouchPointReleased && !overThreshold) {
+            // touchpoint was released near the press position: don't expect any more events, but just handle the release
+            return true;
+        } else if (point.state() == Qt::TouchPointMoved && overThreshold) {
+            // touchpoint was dragged over the drag threshold: accept it, and remember to handle all moves from now on
+            touchId = point.id();
+            return true;
+        }
+    }
     return false;
 }
 #endif
@@ -213,6 +226,8 @@ void QQuickControlPrivate::handleRelease(const QPointF &)
     if ((focusPolicy & Qt::ClickFocus) == Qt::ClickFocus && QGuiApplication::styleHints()->setFocusOnTouchRelease())
         setActiveFocus(q, Qt::MouseFocusReason);
     touchId = -1;
+    pressWasTouch = false;
+    previousPressPos = QPointF();
 }
 
 void QQuickControlPrivate::handleUngrab()
@@ -420,7 +435,7 @@ void QQuickControlPrivate::setContentItem_helper(QQuickItem *item, bool notify)
 
     contentItem = item;
     q->contentItemChange(item, oldContentItem);
-    delete oldContentItem;
+    QQuickControlPrivate::hideOldItem(oldContentItem);
 
     if (item) {
         connect(contentItem.data(), &QQuickItem::baselineOffsetChanged, this, &QQuickControlPrivate::updateBaselineOffset);
@@ -549,7 +564,13 @@ void QQuickControlPrivate::inheritFont(const QFont &font)
     parentFont.resolve(extra.isAllocated() ? extra->requestedFont.resolve() | font.resolve() : font.resolve());
 
     const QFont defaultFont = q->defaultFont();
-    const QFont resolvedFont = parentFont.resolve(defaultFont);
+    QFont resolvedFont = parentFont.resolve(defaultFont);
+    // Since resolving the font will put the family() into the
+    // families() list if it is empty then we need to unset it
+    // so it does not act as if the font has changed (when it
+    // has not actually changed)
+    if (defaultFont.families().isEmpty())
+        resolvedFont.setFamilies(QStringList());
 
     setFont_helper(resolvedFont);
 }
@@ -832,6 +853,54 @@ void QQuickControlPrivate::executeBackground(bool complete)
         quickCompleteDeferred(q, backgroundName(), background);
 }
 
+/*
+    \internal
+
+    Hides an item that was replaced by a newer one, rather than
+    deleting it, as the item is typically created in QML and hence
+    we don't own it.
+*/
+void QQuickControlPrivate::hideOldItem(QQuickItem *item)
+{
+    if (!item)
+        return;
+
+    qCDebug(lcItemManagement) << "hiding old item" << item;
+
+    item->setVisible(false);
+    item->setParentItem(nullptr);
+
+#if QT_CONFIG(accessibility)
+    // Remove the item from the accessibility tree.
+    QQuickAccessibleAttached *accessible = accessibleAttached(item);
+    if (accessible)
+        accessible->setIgnored(true);
+#endif
+}
+
+/*
+    \internal
+
+    Named "unhide" because it's used for cases where an item
+    that was previously hidden by \l hideOldItem() wants to be
+    shown by a control again, such as a ScrollBar in ScrollView.
+*/
+void QQuickControlPrivate::unhideOldItem(QQuickControl *control, QQuickItem *item)
+{
+    Q_ASSERT(item);
+    qCDebug(lcItemManagement) << "unhiding old item" << item;
+
+    item->setVisible(true);
+    item->setParentItem(control);
+
+#if QT_CONFIG(accessibility)
+    // Add the item back in to the accessibility tree.
+    QQuickAccessibleAttached *accessible = accessibleAttached(item);
+    if (accessible)
+        accessible->setIgnored(false);
+#endif
+}
+
 void QQuickControlPrivate::updateBaselineOffset()
 {
     Q_Q(QQuickControl);
@@ -934,6 +1003,9 @@ QQuickControl::~QQuickControl()
     Q_D(QQuickControl);
     d->removeImplicitSizeListener(d->background, QQuickControlPrivate::ImplicitSizeChanges | QQuickItemPrivate::Geometry);
     d->removeImplicitSizeListener(d->contentItem);
+#if QT_CONFIG(accessibility)
+    QAccessible::removeActivationObserver(d);
+#endif
 }
 
 void QQuickControl::itemChange(QQuickItem::ItemChange change, const QQuickItem::ItemChangeData &value)
@@ -1470,9 +1542,9 @@ void QQuickControl::setHovered(bool hovered)
     Setting this property propagates the value to all child controls that do not have
     \c hoverEnabled explicitly set.
 
-    You can also enable or disable hover effects for all Qt Quick Controls 2 applications
+    You can also enable or disable hover effects for all Qt Quick Controls applications
     by setting the \c QT_QUICK_CONTROLS_HOVER_ENABLED \l {Supported Environment Variables
-    in Qt Quick Controls 2}{environment variable}.
+    in Qt Quick Controls}{environment variable}.
 
     \sa hovered
 */
@@ -1584,7 +1656,7 @@ void QQuickControl::setBackground(QQuickItem *background)
     }
 
     d->removeImplicitSizeListener(d->background, QQuickControlPrivate::ImplicitSizeChanges | QQuickItemPrivate::Geometry);
-    delete d->background;
+    QQuickControlPrivate::hideOldItem(d->background);
     d->background = background;
 
     if (background) {
@@ -1626,8 +1698,11 @@ void QQuickControl::setBackground(QQuickItem *background)
     }
     \endcode
 
-    \note The content item is automatically resized to fit within the
-    \l padding of the control.
+    \note The content item is automatically positioned and resized to fit
+    within the \l padding of the control. Bindings to the
+    \l[QtQuick]{Item::}{x}, \l[QtQuick]{Item::}{y},
+    \l[QtQuick]{Item::}{width}, and \l[QtQuick]{Item::}{height}
+    properties of the contentItem are not respected.
 
     \note Most controls use the implicit size of the content item to calculate
     the implicit size of the control itself. If you replace the content item
@@ -2094,6 +2169,10 @@ void QQuickControl::mousePressEvent(QMouseEvent *event)
 {
     Q_D(QQuickControl);
     d->handlePress(event->localPos());
+    if (event->source() == Qt::MouseEventSynthesizedByQt) {
+        d->pressWasTouch = true;
+        d->previousPressPos = event->localPos();
+    }
     event->accept();
 }
 
@@ -2255,12 +2334,13 @@ QAccessible::Role QQuickControl::accessibleRole() const
 
 void QQuickControl::accessibilityActiveChanged(bool active)
 {
+    Q_D(QQuickControl);
     if (!active)
         return;
 
     QQuickAccessibleAttached *accessibleAttached = qobject_cast<QQuickAccessibleAttached *>(qmlAttachedPropertiesObject<QQuickAccessibleAttached>(this, true));
     Q_ASSERT(accessibleAttached);
-    accessibleAttached->setRole(accessibleRole());
+    accessibleAttached->setRole(d->effectiveAccessibleRole());
 }
 #endif
 
@@ -2273,11 +2353,13 @@ QString QQuickControl::accessibleName() const
     return QString();
 }
 
-void QQuickControl::setAccessibleName(const QString &name)
+void QQuickControl::maybeSetAccessibleName(const QString &name)
 {
 #if QT_CONFIG(accessibility)
-    if (QQuickAccessibleAttached *accessibleAttached = QQuickControlPrivate::accessibleAttached(this))
-        accessibleAttached->setName(name);
+    if (QQuickAccessibleAttached *accessibleAttached = QQuickControlPrivate::accessibleAttached(this)) {
+        if (!accessibleAttached->wasNameExplicitlySet())
+            accessibleAttached->setNameImplicitly(name);
+    }
 #else
     Q_UNUSED(name)
 #endif
