@@ -46,6 +46,7 @@ public:
     int width = 0;
     int height = 0;
     QColor color = Qt::transparent;
+    bool cache = true;
 
     enum ResolveProperties {
         NameResolved = 0x0001,
@@ -53,6 +54,7 @@ public:
         WidthResolved = 0x0004,
         HeightResolved = 0x0008,
         ColorResolved = 0x0010,
+        CacheResolved = 0x0020,
         AllPropertiesResolved = 0x1ffff
     };
 
@@ -86,7 +88,8 @@ bool QQuickIcon::operator==(const QQuickIcon &other) const
                             && d->source == other.d->source
                             && d->width == other.d->width
                             && d->height == other.d->height
-                            && d->color == other.d->color);
+                            && d->color == other.d->color
+                            && d->cache == other.d->cache);
 }
 
 bool QQuickIcon::operator!=(const QQuickIcon &other) const
@@ -109,12 +112,14 @@ void QQuickIcon::setName(const QString &name)
     if ((d->resolveMask & QQuickIconPrivate::NameResolved) && d->name == name)
         return;
 
+    d.detach();
     d->name = name;
     d->resolveMask |= QQuickIconPrivate::NameResolved;
 }
 
 void QQuickIcon::resetName()
 {
+    d.detach();
     d->name = QString();
     d->resolveMask &= ~QQuickIconPrivate::NameResolved;
 }
@@ -129,12 +134,14 @@ void QQuickIcon::setSource(const QUrl &source)
     if ((d->resolveMask & QQuickIconPrivate::SourceResolved) && d->source == source)
         return;
 
+    d.detach();
     d->source = source;
     d->resolveMask |= QQuickIconPrivate::SourceResolved;
 }
 
 void QQuickIcon::resetSource()
 {
+    d.detach();
     d->source = QString();
     d->resolveMask &= ~QQuickIconPrivate::SourceResolved;
 }
@@ -149,12 +156,14 @@ void QQuickIcon::setWidth(int width)
     if ((d->resolveMask & QQuickIconPrivate::WidthResolved) && d->width == width)
         return;
 
+    d.detach();
     d->width = width;
     d->resolveMask |= QQuickIconPrivate::WidthResolved;
 }
 
 void QQuickIcon::resetWidth()
 {
+    d.detach();
     d->width = 0;
     d->resolveMask &= ~QQuickIconPrivate::WidthResolved;
 }
@@ -169,12 +178,14 @@ void QQuickIcon::setHeight(int height)
     if ((d->resolveMask & QQuickIconPrivate::HeightResolved) && d->height == height)
         return;
 
+    d.detach();
     d->height = height;
     d->resolveMask |= QQuickIconPrivate::HeightResolved;
 }
 
 void QQuickIcon::resetHeight()
 {
+    d.detach();
     d->height = 0;
     d->resolveMask &= ~QQuickIconPrivate::HeightResolved;
 }
@@ -189,34 +200,62 @@ void QQuickIcon::setColor(const QColor &color)
     if ((d->resolveMask & QQuickIconPrivate::ColorResolved) && d->color == color)
         return;
 
+    d.detach();
     d->color = color;
     d->resolveMask |= QQuickIconPrivate::ColorResolved;
 }
 
 void QQuickIcon::resetColor()
 {
+    d.detach();
     d->color = Qt::transparent;
     d->resolveMask &= ~QQuickIconPrivate::ColorResolved;
 }
 
+bool QQuickIcon::cache() const
+{
+    return d->cache;
+}
+
+void QQuickIcon::setCache(bool cache)
+{
+    if ((d->resolveMask & QQuickIconPrivate::CacheResolved) && d->cache == cache)
+        return;
+
+    d.detach();
+    d->cache = cache;
+    d->resolveMask |= QQuickIconPrivate::CacheResolved;
+}
+
+void QQuickIcon::resetCache()
+{
+    d.detach();
+    d->cache = true;
+    d->resolveMask &= ~QQuickIconPrivate::CacheResolved;
+}
+
 QQuickIcon QQuickIcon::resolve(const QQuickIcon &other) const
 {
     QQuickIcon resolved = *this;
+    resolved.d.detach();
 
     if (!(d->resolveMask & QQuickIconPrivate::NameResolved))
-        resolved.d->name = other.name();
+        resolved.d->name = other.d->name;
 
     if (!(d->resolveMask & QQuickIconPrivate::SourceResolved))
-        resolved.d->source = other.source();
+        resolved.d->source = other.d->source;
 
     if (!(d->resolveMask & QQuickIconPrivate::WidthResolved))
-        resolved.d->width = other.width();
+        resolved.d->width = other.d->width;
 
     if (!(d->resolveMask & QQuickIconPrivate::HeightResolved))
-        resolved.d->height = other.height();
+        resolved.d->height = other.d->height;
 
     if (!(d->resolveMask & QQuickIconPrivate::ColorResolved))
-        resolved.d->color = other.color();
+        resolved.d->color = other.d->color;
+
+    if (!(d->resolveMask & QQuickIconPrivate::CacheResolved))
+        resolved.d->cache = other.d->cache;
 
     return resolved;
 }
